#BEGIN COPYRIGHT
#************************************************************************************
# IBM Confidential
# OCO Source Materials
# 5639-D57,5630-A36,5630-A37,5724-D18
# @ Copyright IBM Corporation 2010.
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#*************************************************************************
#END COPYRIGHT

import sys
from com.ibm.j2ca.migration.wpsruntime.base import WPSMigrationUtil
from java.lang import System

# Retrieve the value of WPS HOME from system environment property
wpsRootPath = WPSMigrationUtil.getSystemProperty("was.install.root")
# Define the script path
fileSeparator=WPSMigrationUtil.getFileSeparator()
scriptsPath=wpsRootPath+fileSeparator+"util"+fileSeparator+"adapterMigration"+fileSeparator
sys.path.append(scriptsPath)
import printHelper as PrintHelper
# Set the environment property value: WPS_HOME
PrintHelper.printInfo("WPS_HOME = "+wpsRootPath)
WPSMigrationUtil.setWPSHome(wpsRootPath)
# Set the environment property value for new adapter RAR path
newRARFolder=wpsRootPath+fileSeparator+"installableApps"+fileSeparator
WPSMigrationUtil.setNewRARDir(newRARFolder)
# Set the environment property value for migration temp folder
tempFolder=WPSMigrationUtil.getSystemProperty("bpm.upgrade.backup.dir")
WPSMigrationUtil.setTempDir(tempFolder)
lineSeparator = System.getProperty("line.separator")


import findEmbeddedRAApplications as FindEmbededRAApps
import findStandaloneRAApplications as FindStandAloneRAApps
import updateEmbededRAR as UpdateEmbededRAR
import updateStandaloneAdapter as UpdateStandAloneAdapter
import migrateApp as MigrateApp

#-------------------------------------------------------------------------------------------
#  Sub modules for embeded adapters/applications migration
#-------------------------------------------------------------------------------------------
def migrateEmbededRAApps(configurationFile):
	embededRAApps = FindEmbededRAApps.findEmbeddedRAApps()
	PrintHelper.printInfo("starting to migrate embedded adapter and applications...")
	PrintHelper.printInfo(embededRAApps)
	
	for app in embededRAApps[:]:
		appName=app[0]
		adapterInfo=app[1]
		for adapter in adapterInfo[:]:
			raName=adapter[0]
			raDisplayName=adapter[1]
			raVersion=adapter[2]
			raURI=adapter[3]
			raID=adapter[4]
			
			if ( WPSMigrationUtil.isSupportedArtifact(raDisplayName, raVersion)):
				# Export the application to ear file under the migration working directory
				migrationWorkDir = WPSMigrationUtil.getMigrationWorkDir()
				try:
					PrintHelper.printInfo("----Embedded application to be migrated = "+appName)
					exportEarFile = migrationWorkDir+appName+".ear"
					AdminApp.export(appName, exportEarFile)
					PrintHelper.printInfo("----Export app "+appName+" to file: "+exportEarFile)

					UpdateEmbededRAR.updateEmbededRAR(exportEarFile, appName, raDisplayName, raVersion, raURI, raID)
					MigrateApp.migrateApp(exportEarFile, appName, configurationFile)
					
					PrintHelper.printInfo("----Embedded application migration Done for app = "+appName)
				except:
					PrintHelper.printInfo("----FAIL: Embedded application migration failed for app = "+appName)
					PrintHelper.printInfo('root cause: '+ sys.exc_type + sys.exc_value)
				# Delete the Work Dir
				if ( WPSMigrationUtil.toRemoveTempFiles() ):
					WPSMigrationUtil.deleteFile(migrationWorkDir)
		#endFor
	#endFor
#end def migrateEmbededRAApps

#-------------------------------------------------------------------------------------------
#  Sub modules for standalone adapters/applications migration
#-------------------------------------------------------------------------------------------
def migrateStandAloneRAApps(configurationFile):
	raStandaloneRAAppList = FindStandAloneRAApps.findStandaloneRAApps()
	PrintHelper.printInfo("starting to migrate stand alone adapter and applications...")
	PrintHelper.printInfo(raStandaloneRAAppList)
	try:
		for oneNode in raStandaloneRAAppList:
			#toMigrateApps = []
			nodeName = oneNode[0]
			nodeID = oneNode[1]
			raApplicationList = oneNode[2]
			for raApplication in raApplicationList:
				raID = raApplication[0]
				raName = raApplication[1]
				raDisplayName = raApplication[2]
				raVersion = raApplication[3]
				raMCFList = raApplication[4]
				raASList = raApplication[5]
				appsList = raApplication[6]
				PrintHelper.printInfo("WebSphere Adapter is "+raName)

				for appName in appsList:
					MigrateApp.migrateStandaloneApp(appName, configurationFile)

				dir = WPSMigrationUtil.getMigrationWorkDir()
				UpdateStandAloneAdapter.saveMCFprop( dir, raDisplayName, raMCFList )
				PrintHelper.printInfo("---saved MCF prop for adapter="+raName)

				UpdateStandAloneAdapter.saveASprop( dir, raDisplayName, raASList, raID )
				PrintHelper.printInfo("---saved AS prop for adapter="+raName)

				UpdateStandAloneAdapter.saveClasspath( dir, raDisplayName, raID )
				PrintHelper.printInfo("---saved classpath for adapter="+raName)

				UpdateStandAloneAdapter.removeRAR(raID,raName,raDisplayName)
				PrintHelper.printInfo("---removed old adapter="+raName)

				UpdateStandAloneAdapter.installRAR(raName,raDisplayName,nodeName)
				PrintHelper.printInfo("---installed new adapter="+raName)

				cell = AdminConfig.list('Cell').split(lineSeparator)[0]
				cellname = cell.split('(')[0]
				id = "/Cell:"+cellname+"/Node:"+nodeName + "/J2CResourceAdapter:" + raName +"/"
				raID = AdminConfig.getid(id)

				PrintHelper.printInfo("Recovering CF/AS for stand alone adapter="+raName+" on node="+nodeName)
				propertyFiles = WPSMigrationUtil.getAllFilesInFolder(dir, ".properties")
				for file in propertyFiles:
					if(file.find(raDisplayName + "_RA_") == 0):
						raProperty = UpdateStandAloneAdapter.getPropertiesFromFile(dir + file)
						UpdateStandAloneAdapter.createRAproperty(raID,raProperty)
					else:
						if (file.find(raDisplayName+"_CF_") == 0):
							mcfProperty = UpdateStandAloneAdapter.getPropertiesFromFile(dir + file)
							UpdateStandAloneAdapter.createConnectionFactory(raID,mcfProperty)
						else:
							if(file.find(raDisplayName+"_AS_") == 0):
								asProperty = UpdateStandAloneAdapter.getPropertiesFromFile(dir + file)
								UpdateStandAloneAdapter.createActivationSpec(dir,raID,raDisplayName,asProperty)
				#end for file in propertyFiles:
				if ( WPSMigrationUtil.toRemoveTempFiles() ):
					WPSMigrationUtil.deleteFile(dir)

			#end for raApplication in raApplicationList:
	except:
		PrintHelper.printInfo("Encounter error:")
		PrintHelper.printInfo(sys.exc_type)
		PrintHelper.printInfo(sys.exc_value)
	#endfor
#end def migrateStandAloneRAApps

def migrateClusterApps(configurationFile):
	#--------------------------------------------------------------
	# Will check the applications that reference to the adapter MCF/AS defined on clusters
	#--------------------------------------------------------------    
	clusterAdapterAppList = FindStandAloneRAApps.findClusterApps()
	
	for oneItem in clusterAdapterAppList:
		raID = oneItem [0]
		raName = oneItem [1]
		raDisplayName = oneItem[2]
		raVersion = oneItem [3]
		clusterAdapterApp = oneItem [4]
		
		for appName in clusterAdapterApp:
			MigrateApp.migrateStandaloneApp(appName, configurationFile)
			PrintHelper.printInfo("----Application "+appName+" on cluster is migrated")
		#end for app

	#endFor -- cluster
#end

def getObjectArray(value):
	from java.lang import String
	objectArray = [];
	# @todo: do we have a space problem here?
	stringValue = String(value);
	if (stringValue.length() != 0):
		objectArray = value.split(lineSeparator);
	return objectArray;
#endDef

def getNodeType():
	nodeType = WPSMigrationUtil.getSystemProperty("bpm.upgrade.node.type")
	if (nodeType==""):
		nodelist = AdminConfig.list('Node')
		nodeArr = FindStandAloneRAApps.wsadminToList(nodelist)
		nodeNum = len(nodeArr)
		if ( nodeNum > 1 ):
			nodeType = "dmgr"
		else:
			nodeType = "node"
	
	return nodeType
#end def getNodeType

def getClusterName():
	clusterName = WPSMigrationUtil.getSystemProperty("bpm.upgrade.cluster.name")
	return clusterName
# end def getClusterName

#-------------------------------------------------------------------------------------------
#  Main program
#-------------------------------------------------------------------------------------------
if __name__ == "__main__":
	configurationFile = scriptsPath+"adapterMigrationInfo.xml"
	PrintHelper.printInfo("----Loading configuration info from "+configurationFile)
	WPSMigrationUtil.getAdapterMigrationInfo(configurationFile)
	
	#if ( WPSMigrationUtil.getCustomProperty("skipAdapterMigration").lower() == "true" ):
	#	PrintHelper.printInfo("----Skip adapter migration...")
	#	return
	
	tempFolder = WPSMigrationUtil.getTempDir();
	PrintHelper.printInfo("Temp Folder = "+tempFolder)

	nodeType = getNodeType()
	clusterName = getClusterName()
	migrationType = ''
		
	if ( nodeType=="dmgr" and ''==clusterName ):
		migrationType = "DMGR"
		PrintHelper.printInfo("---DMGR migration....")
	else:
		if ( nodeType == "dmgr" ):
			migrationType = "Cluster"
			PrintHelper.printInfo("---Cluster migration.... Cluster="+getClusterName())
		else:
			if ( nodeType == "managed" ):
				migrationType = "ManagedNode"
				PrintHelper.printInfo("---Managed Node profile migration.... Node="+MigrateApp.getNodename())
			else:
				migrationType = "UnManagedNode"
				PrintHelper.printInfo("---UnManaged Node profile migration.... Node="+MigrateApp.getNodename())
	
	if ( migrationType == "DMGR" ):
		PrintHelper.printInfo("----adapter migration skip DMGR migration...")
	else:
		# migrate embeded adapters and applications (for both the cluster migration and node migration)
		PrintHelper.printInfo("----Migrating embeded adapters and applications...")
		migrateEmbededRAApps(configurationFile)
		PrintHelper.printInfo("----Done embeded adapters and applications migration\n")

		# migrate stand-alone adapters and applications
		if ( migrationType=="Cluster" ):
			# Run from the DMGR profile/machine
			PrintHelper.printInfo("----Migrating applications on Cluster...")
			migrateClusterApps(configurationFile)
			PrintHelper.printInfo("----Done applications migration on Cluster...")
		else:
			# migration for node profile
			if ( nodeType == "managed"):
				PrintHelper.printInfo("----Standalone adapter migration on managed node will be performed in BPMProfileUpgrade step...")
			else:
				nodeName = MigrateApp.getNodename();
				PrintHelper.printInfo("----Migrating standalone adapters and applications on node="+nodeName+"...")
				migrateStandAloneRAApps(configurationFile)
				PrintHelper.printInfo("----Done standalone adapters and applications migration on node="+nodeName+"...\n")

	PrintHelper.printInfo("----Profile migration done")
	
#end of main program