-- --------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2008 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ---------------------------------------------

--
--  Create temporary tables, copy the original data into them and drop the original tables
--      This is just to make sure all of the indexes on the original table are gone.
--

CREATE TABLE w_temp_uri (
    id INTEGER NOT NULL, 
    uri VARCHAR(254) NOT NULL, 
    namespace_id INTEGER NOT NULL )  
 IN USERSPACE1; 

INSERT INTO w_temp_uri SELECT * FROM w_uri;
DROP TABLE w_uri;

CREATE TABLE w_temp_statement (
    id INTEGER NOT NULL, 
    version_from INTEGER NOT NULL, 
    version_to INTEGER NOT NULL, 
    subj_id INTEGER NOT NULL, 
    pred_id INTEGER NOT NULL, 
    obj_id INTEGER NOT NULL, 
    obj_typ_cd INTEGER NOT NULL,
    partition_id INTEGER NOT NULL)  
 IN USERSPACE1; 


INSERT INTO w_temp_statement SELECT * FROM w_statement;
DROP TABLE w_statement;

--
-- Recreate the tables with the new indexes
--

CREATE TABLE w_uri (
    id INTEGER NOT NULL, 
    uri VARCHAR(254) NOT NULL, 
    namespace_id INTEGER NOT NULL )  
 IN USERSPACE1; 

ALTER TABLE w_uri ADD PRIMARY KEY (id);

CREATE UNIQUE INDEX idx_uri ON w_uri (uri ASC);
CREATE UNIQUE INDEX idx_uri_by_ns ON w_uri (namespace_id, id);

ALTER TABLE w_uri 
	ADD CONSTRAINT w_uri_fk_namesp FOREIGN KEY
		(namespace_id)
	REFERENCES w_namespace
		(id)
	ON DELETE NO ACTION
	ON UPDATE NO ACTION
	ENFORCED
	ENABLE QUERY OPTIMIZATION;

CREATE TABLE w_statement (
    id INTEGER NOT NULL, 
    version_from INTEGER NOT NULL, 
    version_to INTEGER NOT NULL, 
    subj_id INTEGER NOT NULL, 
    pred_id INTEGER NOT NULL, 
    obj_id INTEGER NOT NULL, 
    obj_typ_cd INTEGER NOT NULL,
    partition_id INTEGER NOT NULL)  
 IN USERSPACE1; 

ALTER TABLE w_statement ADD PRIMARY KEY (id);

CREATE INDEX idx_smt_by_sbj ON w_statement (subj_id, version_from, version_to);
CREATE INDEX idx_smt_by_fvr ON w_statement (version_from);
CREATE INDEX idx_sbj_by_prp ON w_statement (pred_id, obj_id);
CREATE INDEX idx_smt_by_val ON w_statement (obj_id, subj_id);
CREATE INDEX idx_val_by_prp ON w_statement (subj_id, pred_id);

--
--  Copy the data from the temporary tables back into the original tables and drop the temporary tables
--

INSERT INTO W_STATEMENT SELECT * FROM W_TEMP_STATEMENT;
DROP TABLE W_TEMP_STATEMENT;

INSERT INTO W_URI SELECT * FROM W_TEMP_URI;
DROP TABLE W_TEMP_URI;

-----------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2009 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------

CREATE TABLE w_locale (
    id INTEGER NOT NULL, 
    locale VARCHAR(8) NOT NULL)
 IN USERSPACE1;
 
ALTER TABLE w_locale ADD PRIMARY KEY (id);

ALTER TABLE w_locale ADD CONSTRAINT unique_locale UNIQUE(locale);

INSERT INTO w_locale VALUES (1000, '');
INSERT INTO w_locale VALUES (1001, 'en');
INSERT INTO w_locale VALUES (1002, 'en-us');
INSERT INTO w_locale VALUES (1003, 'en-uk');
INSERT INTO w_locale VALUES (1004, 'en-gb');
INSERT INTO w_locale VALUES (1032, 'cs');
INSERT INTO w_locale VALUES (1064, 'es');
INSERT INTO w_locale VALUES (1096, 'de');
INSERT INTO w_locale VALUES (1128, 'de-de');
INSERT INTO w_locale VALUES (1129, 'fr');
INSERT INTO w_locale VALUES (1160, 'fr-ca-sk');
INSERT INTO w_locale VALUES (1161, 'hu');
INSERT INTO w_locale VALUES (1192, 'it');
INSERT INTO w_locale VALUES (1224, 'ja');
INSERT INTO w_locale VALUES (1256, 'ko');
INSERT INTO w_locale VALUES (1288, 'pl');
INSERT INTO w_locale VALUES (1320, 'pt-br');
INSERT INTO w_locale VALUES (1352, 'ru');
INSERT INTO w_locale VALUES (1384, 'zh');
INSERT INTO w_locale VALUES (1416, 'zh-tw');
INSERT INTO w_locale VALUES (1448, 'el');

-- Commit the active changeset which prevents the bootstrap of additional 
-- content either during migration or after installing stack product such as Fabric.
UPDATE w_statement 
        SET obj_id=(SELECT id FROM w_obj_lit_string WHERE litval='PUBLISHED') 
	WHERE pred_id=(SELECT id FROM w_uri WHERE uri LIKE '%changeSetState')
	AND obj_id IN (SELECT id FROM w_obj_lit_string WHERE litval IN ('DRAFT', 'PENDING' , 'APPROVED'))
	AND obj_typ_cd=6
	AND version_to=2000000000;

-- Can't drop plain until contents copied into 
-- w_string, with lang in w_statement.

UPDATE w_statement SET obj_id 
 = (SELECT w_lit_bool.litval FROM w_lit_bool
     WHERE w_statement.obj_id = w_lit_bool.id)
WHERE w_statement.obj_typ_cd = 7;

UPDATE w_statement SET obj_id 
 = (SELECT w_lit_int.litval FROM w_lit_int
     WHERE w_statement.obj_id = w_lit_int.id)
WHERE w_statement.obj_typ_cd = 2;

-- Merging string and plain:
-- 1. Canonicalize locale.

UPDATE w_obj_lit_plain SET xml_lang = '' WHERE xml_lang is null;


-- Guarantee no ID collisions during the copy:

UPDATE w_statement
   SET obj_id = (1 + obj_id + (SELECT max(id) from w_obj_lit_string))
 WHERE obj_typ_cd = 11;

UPDATE w_obj_lit_plain 
  SET id = (1 + id + (SELECT max(id) FROM w_obj_lit_string));

-- 3. Copy from plain into string table, with null  hash.

INSERT INTO w_obj_lit_string (id, large, litval) 
  SELECT id, large, litval
    FROM w_obj_lit_plain;

-- Use locale table to get type codes for plains.
UPDATE w_statement SET obj_typ_cd 
  = (SELECT w_locale.id FROM w_locale
      WHERE w_locale.locale =
              (SELECT w_obj_lit_plain.xml_lang 
                 FROM w_obj_lit_plain 
                WHERE w_statement.obj_id = w_obj_lit_plain.id))
WHERE w_statement.obj_typ_cd = 11;

-- The old object IDs in the string table haven't changed, but
-- the type code has. 
UPDATE w_statement SET obj_typ_cd = 999 WHERE obj_typ_cd = 6;

-- Cleanup

DROP TABLE w_obj_lit_plain;
DROP TABLE w_lit_int;
DROP TABLE w_lit_bool;

DROP SEQUENCE seq_w_obj_lit_plain_id;
DROP SEQUENCE seq_w_lit_int_id;
DROP SEQUENCE seq_w_lit_bool_id;


-- Pattern tables for query optimization

CREATE TABLE w_subj_pred_index (
    subj_id INTEGER NOT NULL REFERENCES w_uri (id),
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (subj_id, version_from, version_to, partition_id)
);

CREATE TABLE w_subj_obj_index (
    subj_id INTEGER NOT NULL REFERENCES w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (subj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_pred_subj_index (
    pred_id INTEGER NOT NULL REFERENCES w_uri (id),
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (pred_id, version_from, version_to, partition_id)
);

CREATE TABLE w_pred_obj_index (
    pred_id INTEGER NOT NULL REFERENCES w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (pred_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_obj_subj_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_obj_pred_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);


