-----------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------

------------------------------------------------
-- DDL Statements for table W_NAMESPACE
------------------------------------------------


CREATE TABLESPACE EWSRR2
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_NAMESPACE  (
ID INTEGER NOT NULL ,
NAMESPACE VARCHAR(255) NOT NULL,Primary key(id),UNIQUE(NAMESPACE))
IN @DB_NAME@.EWSRR2;

CREATE UNIQUE INDEX @SCHEMA@.W_NAMESPACE1
ON @SCHEMA@.W_NAMESPACE(ID ASC);

CREATE UNIQUE INDEX  @SCHEMA@.W_NAME_SPC1
ON @SCHEMA@.W_NAMESPACE(NAMESPACE ASC);

------------------------------------------------
-- DDL Statements for table @SCHEMA@.W_STATEMENT
------------------------------------------------


CREATE TABLESPACE EWSRR3
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_STATEMENT  (
ID INTEGER NOT NULL  ,
VERSION_FROM INTEGER NOT NULL ,
VERSION_TO INTEGER ,
PRED_ID INTEGER NOT NULL ,
SUBJ_ID INTEGER NOT NULL ,
OBJ_ID INTEGER NOT NULL ,
OBJ_TYP_CD INTEGER NOT NULL ,
PARTITION_ID INTEGER NOT NULL,Primary key(id) )
IN @DB_NAME@.EWSRR3;

CREATE UNIQUE INDEX @SCHEMA@.W_STATEMENT1
ON @SCHEMA@.W_STATEMENT(ID ASC);

CREATE INDEX @SCHEMA@.IDX_SBJ_BY_PRP
ON @SCHEMA@.W_STATEMENT 
  (PRED_ID ASC,OBJ_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SBJ_BY_VAL
ON @SCHEMA@.W_STATEMENT (OBJ_ID ASC, SUBJ_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SMT_BY_SBJ
ON @SCHEMA@.W_STATEMENT (SUBJ_ID ASC, VERSION_FROM ASC, 
   VERSION_TO ASC);

CREATE INDEX @SCHEMA@.IDX_VAL_BY_PRP
ON @SCHEMA@.W_STATEMENT (SUBJ_ID ASC,PRED_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SMT_BY_FVR
ON @SCHEMA@.W_STATEMENT (VERSION_FROM ASC);



------------------------------------------------
-- DDL Statements for table W_URI
------------------------------------------------


CREATE TABLESPACE EWSRR4
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_URI  (
ID INTEGER NOT NULL ,
URI VARCHAR(255) NOT NULL ,
NAMESPACE_ID INTEGER NOT NULL,Primary key(id),UNIQUE(URI))
IN @DB_NAME@.EWSRR4;

ALTER TABLE @SCHEMA@.W_URI
ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY
(NAMESPACE_ID)
REFERENCES @SCHEMA@.W_NAMESPACE
(ID)
ON DELETE NO ACTION
ENFORCED
ENABLE QUERY OPTIMIZATION;

CREATE UNIQUE INDEX @SCHEMA@.W_URI1
ON @SCHEMA@.W_URI (ID ASC);

CREATE UNIQUE INDEX  @SCHEMA@.W_URI
ON @SCHEMA@.W_URI(URI ASC);

------------------------------------------------
-- DDL Statements for table W_VERSION
------------------------------------------------

CREATE TABLESPACE EWSRR5
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_VERSION  (
ID INTEGER NOT NULL ,
PARTITION_ID INTEGER NOT NULL,
USERNAME VARCHAR(64) NOT NULL ,
CHANGE_TIME TIMESTAMP NOT NULL ,
CL_GID VARCHAR(36) ,
CL_LID VARCHAR(10) ,
SCHEMA_NS_ID INTEGER ,
SCHEMA_REV INTEGER NOT NULL )
IN @DB_NAME@.EWSRR5;

CREATE INDEX @SCHEMA@.W_VERSION1
ON @SCHEMA@.W_VERSION(ID ASC);

CREATE INDEX @SCHEMA@.W_VERSION2
ON @SCHEMA@.W_VERSION (SCHEMA_NS_ID);

CREATE UNIQUE INDEX @SCHEMA@.W_VERS_IN2
ON @SCHEMA@.W_VERSION(ID ASC, PARTITION_ID ASC);

ALTER TABLE @SCHEMA@.W_VERSION
    ADD PRIMARY KEY (ID, PARTITION_ID);

ALTER TABLE @SCHEMA@.W_VERSION
ADD CONSTRAINT W_VER_FK_NAMESP FOREIGN KEY
(SCHEMA_NS_ID)
REFERENCES @SCHEMA@.W_NAMESPACE
(ID)
ON DELETE NO ACTION
ENFORCED
ENABLE QUERY OPTIMIZATION;

------------------------------------------------
-- DDL Statements for table W_OBJ_LIT_ANY
------------------------------------------------

CREATE TABLESPACE EWSRR6
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_ANY  (
ID INTEGER NOT NULL ,
TYPE_URI VARCHAR(255) NOT NULL ,
HASH VARCHAR(40) ,
LARGE BLOB(10000000),Primary key(id) )
IN @DB_NAME@.EWSRR6;

CREATE UNIQUE INDEX @SCHEMA@.W_OBJ_LIT_ANY1
ON @SCHEMA@.W_OBJ_LIT_ANY(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_ANY
ON @SCHEMA@.W_OBJ_LIT_ANY (TYPE_URI ASC);

CREATE LOB TABLESPACE EWSRR6L               
  IN @DB_NAME@                               
  USING STOGROUP @STOGRP@                    
  LOCKSIZE LOB                              
  BUFFERPOOL @BPLOB4K@;                           
                                            
CREATE AUX TABLE @SCHEMA@.W_OBJ_LIT_ANYAUX    
 IN @DB_NAME@.EWSRR6L                        
 STORES @SCHEMA@.W_OBJ_LIT_ANY COLUMN LARGE;  
                                            
CREATE INDEX @SCHEMA@.W_OBJ_LIT_ANYAUX_IDX    
 ON @SCHEMA@.W_OBJ_LIT_ANYAUX                 
 USING STOGROUP @STOGRP@                     
 BUFFERPOOL @BPINDEX@;                            

------------------------------------------------
-- DDL Statements for table W_LIT_DOUBLE
------------------------------------------------


CREATE TABLESPACE EWSRR9
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LIT_DOUBLE  (
ID INTEGER NOT NULL ,
LITVAL DOUBLE,Primary key(id) )
IN @DB_NAME@.EWSRR9;

CREATE UNIQUE INDEX @SCHEMA@.W_LIT_DOUBLE1
ON @SCHEMA@.W_LIT_DOUBLE(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_DBL
ON @SCHEMA@.W_LIT_DOUBLE (LITVAL ASC);

------------------------------------------------
-- DDL Statements for table W_LIT_FLOAT
------------------------------------------------


CREATE TABLESPACE EWSRR10
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LIT_FLOAT  (
ID INTEGER NOT NULL ,
LITVAL DOUBLE,Primary key(id) )
IN @DB_NAME@.EWSRR10;

CREATE UNIQUE INDEX @SCHEMA@.W_LIT_FLOAT1
ON @SCHEMA@.W_LIT_FLOAT(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_FLT
ON @SCHEMA@.W_LIT_FLOAT (LITVAL ASC);


------------------------------------------------
-- DDL Statements for table W_LIT_LONG
------------------------------------------------


CREATE TABLESPACE EWSRR12
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LIT_LONG  (
ID INTEGER NOT NULL ,
LITVAL DECIMAL(19, 0),Primary key(id) )
IN @DB_NAME@.EWSRR12;

CREATE UNIQUE INDEX @SCHEMA@.W_LIT_LONG1
ON @SCHEMA@.W_LIT_LONG(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_LONG
ON @SCHEMA@.W_LIT_LONG (LITVAL ASC);

------------------------------------------------
-- DDL Statements for table W_OBJ_LIT_DATE
------------------------------------------------


CREATE TABLESPACE EWSRR13
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_DATE  (
ID INTEGER NOT NULL ,
LITVAL TIMESTAMP,Primary key(id) )
IN @DB_NAME@.EWSRR13;

CREATE UNIQUE INDEX @SCHEMA@.W_OBJ_LIT_DATE1
ON @SCHEMA@.W_OBJ_LIT_DATE(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_DATE
ON @SCHEMA@.W_OBJ_LIT_DATE (LITVAL ASC);

------------------------------------------------
-- DDL Statements for table W_OBJ_LIT_DATETIME
------------------------------------------------


CREATE TABLESPACE EWSRR14
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_DATETIME  (
ID INTEGER NOT NULL ,
LITVAL TIMESTAMP,Primary key(id) )
IN @DB_NAME@.EWSRR14;

CREATE UNIQUE INDEX @SCHEMA@.W_OBJ_LIT_DATETIME1
ON @SCHEMA@.W_OBJ_LIT_DATETIME(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_TIME
ON @SCHEMA@.W_OBJ_LIT_DATETIME (LITVAL ASC);

-- DDL Statements for table W_OBJ_LIT_STRING
------------------------------------------------

CREATE TABLESPACE EWSRR15
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_OBJ_LIT_STRING (
ID  INTEGER NOT NULL  ,
HASH VARCHAR(40) ,
LITVAL VARCHAR(1024) ,
LARGE BLOB(10000000) ,Primary key(id))
IN @DB_NAME@.EWSRR15;

CREATE UNIQUE INDEX  @SCHEMA@.W_OBJ_LIT_STRING1
ON @SCHEMA@.W_OBJ_LIT_STRING(ID ASC);

CREATE INDEX @SCHEMA@.IDX_OBJ_STR
ON @SCHEMA@.W_OBJ_LIT_STRING (HASH ASC);

CREATE LOB TABLESPACE EWSRR15L                     
  IN @DB_NAME@                                     
  USING STOGROUP @STOGRP@
  LOCKSIZE LOB                                    
  BUFFERPOOL @BPLOB4K@;                                 
                                                  
CREATE AUX TABLE @SCHEMA@.W_OBJ_LIT_STRINGAUX              
   IN @DB_NAME@.EWSRR15L                            
   STORES @SCHEMA@.W_OBJ_LIT_STRING COLUMN LARGE;   
                                                  
CREATE INDEX @SCHEMA@.W_OBJ_LIT_STRINGAUX_IDX       
 ON @SCHEMA@.W_OBJ_LIT_STRINGAUX                    
 USING STOGROUP @STOGRP@
 BUFFERPOOL @BPINDEX@;

------------------------------------------------
-- DDL Statements for table W_ARTIFACT_BLOB
------------------------------------------------


CREATE TABLESPACE EWSRR16
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_ARTIFACT_BLOB (
 ID VARCHAR(254) NOT NULL,
 CONTENT BLOB(1G), 
 DELETED SMALLINT, Primary key(id))
IN @DB_NAME@.EWSRR16;

CREATE UNIQUE INDEX @SCHEMA@.W_ARTIFACT_BLOB1
ON @SCHEMA@.W_ARTIFACT_BLOB (ID ASC);

CREATE LOB TABLESPACE EWSRR16L                    
  IN @DB_NAME@                                     
  USING STOGROUP @STOGRP@                          
  LOCKSIZE LOB                                    
  BUFFERPOOL @BPLOB4K@;                                 
                                                  
CREATE AUX TABLE @SCHEMA@.W_ARTIFACT_BLOBAUX       
   IN @DB_NAME@.EWSRR16L                          
   STORES @SCHEMA@.W_ARTIFACT_BLOB COLUMN CONTENT; 
                                                  
CREATE INDEX @SCHEMA@.W_ARTIFACT_BLOBAUX_IDX        
 ON @SCHEMA@.W_ARTIFACT_BLOBAUX                     
 USING STOGROUP @STOGRP@                           
 BUFFERPOOL @BPINDEX@;                                  
 
 
------------------------------------------------
-- DDL Statements for table W_LOCALE
------------------------------------------------

CREATE TABLESPACE EWSRR17
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LOCALE (
 ID INTEGER NOT NULL,
 LOCALE VARCHAR(8) NOT NULL,Primary key(id))
IN @DB_NAME@.EWSRR17;

CREATE UNIQUE INDEX @SCHEMA@.W_LOCALE1
ON @SCHEMA@.W_LOCALE(ID ASC);

INSERT INTO @SCHEMA@.W_LOCALE VALUES (1000, '');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1001, 'en');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1002, 'en-us');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1003, 'en-uk');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1004, 'en-gb');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1032, 'cs');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1064, 'es');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1096, 'de');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1128, 'de-de');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1129, 'fr');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1160, 'fr-ca-sk');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1161, 'hu');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1192, 'it');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1224, 'ja');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1256, 'ko');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1288, 'pl');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1320, 'pt-br');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1352, 'ru');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1384, 'zh');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1416, 'zh-tw');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1448, 'el');


----------------------------------------------------------
---Creating sequence objects for Triple store
----------------------------------------------------------

CREATE SEQUENCE @SCHEMA@.SEQ_W_LIT_DOUBLE_ID
 as integer START WITH 1000 increment by 1
 no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_LIT_FLOAT_ID
as integer START WITH 1000 increment by 1
 no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_LIT_LONG_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_NAMESPACE_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_ANY_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_DATE_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_DATETIME_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_OBJ_LIT_STRING_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_STATEMENT_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_URI_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

CREATE SEQUENCE @SCHEMA@.SEQ_W_VERSION_ID
as integer START WITH 1000 increment by 1
no  MAXVALUE  MINVALUE 1001
NO CYCLE CACHE 20 ORDER ;

--
--

-- Pattern tables for query optimization

CREATE TABLESPACE EWSRR18
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_subj_pred_index (
    subj_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, version_from, version_to, partition_id)
) IN @DB_NAME@.EWSRR18;

CREATE UNIQUE INDEX @SCHEMA@.w_subj_pred_idx
 ON @SCHEMA@.w_subj_pred_index(subj_id, version_from, version_to,
    partition_id);

CREATE TABLESPACE EWSRR19
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_subj_obj_index (
    subj_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, obj_typ_cd, version_from, version_to,
      partition_id)
) IN @DB_NAME@.EWSRR19;

CREATE UNIQUE INDEX @SCHEMA@.w_subj_obj_idx
 ON @SCHEMA@.w_subj_obj_index(subj_id, obj_typ_cd, version_from, 
   version_to, partition_id);

CREATE TABLESPACE EWSRR20
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_pred_subj_index (
    pred_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, version_from, version_to, partition_id)
) IN @DB_NAME@.EWSRR20;

CREATE UNIQUE INDEX @SCHEMA@.w_pred_subj_idx
 ON @SCHEMA@.w_pred_subj_index(pred_id, version_from, version_to, 
   partition_id);

CREATE TABLESPACE EWSRR21
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_pred_obj_index (
    pred_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, obj_typ_cd, version_from, version_to, 
     partition_id)
) IN @DB_NAME@.EWSRR21;

CREATE UNIQUE INDEX @SCHEMA@.w_pred_obj_idx
 ON @SCHEMA@.w_pred_obj_index(pred_id, obj_typ_cd, version_from,
   version_to, partition_id);

CREATE TABLESPACE EWSRR22
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_obj_subj_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, 
       version_to, partition_id)
) IN @DB_NAME@.EWSRR22;

CREATE UNIQUE INDEX @SCHEMA@.w_obj_subj_idx
 ON @SCHEMA@.w_obj_subj_index(obj_id, obj_typ_cd, version_from, 
  version_to, partition_id);

CREATE TABLESPACE EWSRR23
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_obj_pred_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to,
      partition_id)
) IN @DB_NAME@.EWSRR23;

CREATE UNIQUE INDEX @SCHEMA@.w_obj_pred_idx
 ON @SCHEMA@.w_obj_pred_index(obj_id, obj_typ_cd, version_from,
   version_to, partition_id);


------------------------------------------------
-- DDL Statements for table W_DBVERSION
------------------------------------------------

CREATE TABLESPACE EWSRR1
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_DBVERSION (
 SUBSYSTEM VARCHAR(8) NOT NULL , 
 CUR_VERSION INTEGER NOT NULL)
IN @DB_NAME@.EWSRR1;

CREATE UNIQUE INDEX @SCHEMA@.W_DBVERSON1
ON @SCHEMA@.W_DBVERSION(SUBSYSTEM ASC);
