
-----------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2008 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------

--
--  Create temporary tables, copy the original data 
--  into them and drop the original tables
--  This is just to make sure all of the indexes on the 
--  original table are gone.
--

CREATE TABLESPACE EWSRR50
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_TEMP_URI  (
    ID INTEGER NOT NULL ,
    URI VARCHAR(255) NOT NULL ,
    NAMESPACE_ID INTEGER NOT NULL )
IN @DB_NAME@.EWSRR50;

INSERT INTO @SCHEMA@.W_TEMP_URI SELECT * FROM @SCHEMA@.W_URI;
DROP TABLE @SCHEMA@.W_URI;

CREATE TABLESPACE EWSRR51
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_TEMP_STATEMENT  (
    ID INTEGER NOT NULL  ,
    VERSION_FROM INTEGER NOT NULL ,
    VERSION_TO INTEGER ,
    PRED_ID INTEGER NOT NULL ,
    SUBJ_ID INTEGER NOT NULL ,
    OBJ_ID INTEGER NOT NULL ,
    OBJ_TYP_CD INTEGER NOT NULL ,
    PARTITION_ID INTEGER NOT NULL)
IN @DB_NAME@.EWSRR51;

INSERT INTO @SCHEMA@.W_TEMP_STATEMENT 
     SELECT * FROM @SCHEMA@.W_STATEMENT;
DROP TABLE @SCHEMA@.W_STATEMENT;


--
-- Recreate the tables with the new indexes
--

CREATE TABLE @SCHEMA@.W_URI  (
    ID INTEGER NOT NULL ,
    URI VARCHAR(255) NOT NULL ,
    NAMESPACE_ID INTEGER NOT NULL,Primary key(id),UNIQUE(URI))
IN @DB_NAME@.EWSRR4;

ALTER TABLE @SCHEMA@.W_URI
ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY
(NAMESPACE_ID)
REFERENCES @SCHEMA@.W_NAMESPACE
(ID)
ON DELETE NO ACTION
ENFORCED
ENABLE QUERY OPTIMIZATION;

CREATE UNIQUE INDEX @SCHEMA@.W_URI1
ON @SCHEMA@.W_URI (ID ASC);

CREATE UNIQUE INDEX  @SCHEMA@.W_URI
ON @SCHEMA@.W_URI(URI ASC);



CREATE TABLE @SCHEMA@.W_STATEMENT  (
ID INTEGER NOT NULL  ,
VERSION_FROM INTEGER NOT NULL ,
VERSION_TO INTEGER ,
PRED_ID INTEGER NOT NULL ,
SUBJ_ID INTEGER NOT NULL ,
OBJ_ID INTEGER NOT NULL ,
OBJ_TYP_CD INTEGER NOT NULL ,
PARTITION_ID INTEGER NOT NULL,Primary key(id) )
IN @DB_NAME@.EWSRR3;

CREATE UNIQUE INDEX @SCHEMA@.W_STATEMENT1
ON @SCHEMA@.W_STATEMENT(ID ASC);

CREATE INDEX @SCHEMA@.IDX_SBJ_BY_PRP
ON @SCHEMA@.W_STATEMENT 
  (PRED_ID ASC,OBJ_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SBJ_BY_VAL
ON @SCHEMA@.W_STATEMENT (OBJ_ID ASC, SUBJ_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SMT_BY_SBJ
ON @SCHEMA@.W_STATEMENT (SUBJ_ID ASC, VERSION_FROM ASC,
    VERSION_TO ASC);

CREATE INDEX @SCHEMA@.IDX_VAL_BY_PRP
ON @SCHEMA@.W_STATEMENT (SUBJ_ID ASC,PRED_ID ASC);

CREATE INDEX @SCHEMA@.IDX_SMT_BY_FVR
ON @SCHEMA@.W_STATEMENT (VERSION_FROM ASC);

--
-- Clean up temporary tablespaces:
-- 

DROP TABLESPACE @DB_NAME@.EWSRR50;
DROP TABLESPACE @DB_NAME@.EWSRR51;
-----------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2009 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------


-- DDL Statements for table W_LOCALE
------------------------------------------------

CREATE TABLESPACE EWSRR17
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.W_LOCALE (
 ID INTEGER NOT NULL,
 LOCALE VARCHAR(8) NOT NULL,Primary key(id))
IN @DB_NAME@.EWSRR17;

CREATE UNIQUE INDEX @SCHEMA@.W_LOCALE1
ON @SCHEMA@.W_LOCALE(ID ASC);

INSERT INTO @SCHEMA@.W_LOCALE VALUES (1000, '');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1001, 'en');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1002, 'en-us');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1003, 'en-uk');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1004, 'en-gb');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1032, 'cs');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1064, 'es');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1096, 'de');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1128, 'de-de');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1129, 'fr');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1160, 'fr-ca-sk');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1161, 'hu');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1192, 'it');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1224, 'ja');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1256, 'ko');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1288, 'pl');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1320, 'pt-br');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1352, 'ru');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1384, 'zh');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1416, 'zh-tw');
INSERT INTO @SCHEMA@.W_LOCALE VALUES (1448, 'el');

-- Commit the active changeset which prevents the bootstrap of additional 
-- content either during migration or after installing stack product such as Fabric.
UPDATE @SCHEMA@.w_statement 
        SET obj_id=(SELECT id FROM @SCHEMA@.w_obj_lit_string WHERE litval='PUBLISHED') 
	WHERE pred_id=(SELECT id FROM @SCHEMA@.w_uri WHERE uri LIKE '%changeSetState')
	AND obj_id IN (SELECT id FROM @SCHEMA@.w_obj_lit_string WHERE litval IN ('DRAFT', 'PENDING' , 'APPROVED'))
	AND obj_typ_cd=6
	AND version_to=2000000000;


-- Can't drop plain until contents copied into 
-- w_string, with lang in w_statement.

UPDATE @SCHEMA@.w_statement SET obj_id 
 = (SELECT @SCHEMA@.w_lit_bool.litval FROM @SCHEMA@.w_lit_bool
     WHERE @SCHEMA@.w_statement.obj_id = @SCHEMA@.w_lit_bool.id)
WHERE @SCHEMA@.w_statement.obj_typ_cd = 7;

UPDATE @SCHEMA@.w_statement SET obj_id 
 = (SELECT @SCHEMA@.w_lit_int.litval FROM @SCHEMA@.w_lit_int
     WHERE @SCHEMA@.w_statement.obj_id = @SCHEMA@.w_lit_int.id)
WHERE @SCHEMA@.w_statement.obj_typ_cd = 2;

-- Merging string and plain:
-- 1. Canonicalize locale.

UPDATE @SCHEMA@.w_obj_lit_plain SET xml_lang = ''
   WHERE xml_lang is null;


-- Guarantee no ID collisions during the copy:

UPDATE @SCHEMA@.w_statement
   SET obj_id = (obj_id + 1 + (SELECT max(id) 
                                FROM @SCHEMA@.w_obj_lit_string))
 WHERE obj_typ_cd = 11;

UPDATE @SCHEMA@.w_obj_lit_plain 
  SET id = (id + 1 + (SELECT max(@SCHEMA@.w_obj_lit_string.id) 
                       FROM @SCHEMA@.w_obj_lit_string));


-- 3. Copy from plain into string table, with null  hash.

INSERT INTO @SCHEMA@.w_obj_lit_string (id, large, litval) 
  SELECT id, cast(large as BLOB(10000000)), litval
    FROM @SCHEMA@.w_obj_lit_plain;

-- Use locale table to get type codes for plains.
UPDATE @SCHEMA@.w_statement SET obj_typ_cd 
  = (SELECT @SCHEMA@.w_locale.id FROM @SCHEMA@.w_locale
      WHERE @SCHEMA@.w_locale.locale =
              (SELECT @SCHEMA@.w_obj_lit_plain.xml_lang 
                 FROM @SCHEMA@.w_obj_lit_plain 
                WHERE @SCHEMA@.w_statement.obj_id 
                     = @SCHEMA@.w_obj_lit_plain.id))
WHERE @SCHEMA@.w_statement.obj_typ_cd = 11;

-- The old object IDs in the string table haven't changed, but
-- the type code has. 
UPDATE @SCHEMA@.w_statement SET obj_typ_cd = 999 WHERE obj_typ_cd = 6;

-- Cleanup

DROP TABLE @SCHEMA@.w_obj_lit_plain;
DROP TABLE @SCHEMA@.w_lit_int;
DROP TABLE @SCHEMA@.w_lit_bool;

DROP SEQUENCE @SCHEMA@.seq_w_obj_lit_plain_id;
DROP SEQUENCE @SCHEMA@.seq_w_lit_int_id;
DROP SEQUENCE @SCHEMA@.seq_w_lit_bool_id;


--
--

-- Pattern tables for query optimization

CREATE TABLESPACE EWSRR18
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_subj_pred_index (
    subj_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, version_from, version_to, partition_id)
) IN @DB_NAME@.EWSRR18;

CREATE UNIQUE INDEX @SCHEMA@.w_subj_pred_idx
 ON @SCHEMA@.w_subj_pred_index(subj_id, version_from, 
      version_to, partition_id);

CREATE TABLESPACE EWSRR19
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_subj_obj_index (
    subj_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (subj_id, obj_typ_cd, version_from,
                 version_to, partition_id)
) IN @DB_NAME@.EWSRR19;

CREATE UNIQUE INDEX @SCHEMA@.w_subj_obj_idx
 ON @SCHEMA@.w_subj_obj_index(subj_id, obj_typ_cd, version_from, 
     version_to, partition_id);

CREATE TABLESPACE EWSRR20
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_pred_subj_index (
    pred_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, version_from, version_to, partition_id)
) IN @DB_NAME@.EWSRR20;

CREATE UNIQUE INDEX @SCHEMA@.w_pred_subj_idx
 ON @SCHEMA@.w_pred_subj_index(pred_id, version_from, 
     version_to, partition_id);

CREATE TABLESPACE EWSRR21
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_pred_obj_index (
    pred_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARCHAR (1024) FOR BIT DATA,
    obj_typ_cd INTEGER NOT NULL,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (pred_id, obj_typ_cd, version_from, version_to,
                  partition_id)
) IN @DB_NAME@.EWSRR21;

CREATE UNIQUE INDEX @SCHEMA@.w_pred_obj_idx
 ON @SCHEMA@.w_pred_obj_index(pred_id, obj_typ_cd, version_from,
    version_to, partition_id);

CREATE TABLESPACE EWSRR22
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_obj_subj_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    subject_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, 
                 partition_id)
) IN @DB_NAME@.EWSRR22;

CREATE UNIQUE INDEX @SCHEMA@.w_obj_subj_idx
 ON @SCHEMA@.w_obj_subj_index(obj_id, obj_typ_cd, version_from, 
   version_to, partition_id);

CREATE TABLESPACE EWSRR23
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  DEFINE NO
  SEGSIZE 32
  LOCKSIZE ANY
  BUFFERPOOL @BPTABLE4K@
  CCSID UNICODE;

CREATE TABLE @SCHEMA@.w_obj_pred_index (
    obj_id INTEGER NOT NULL,
    obj_typ_cd INTEGER NOT NULL,
    predicate_map VARCHAR (1024) FOR BIT DATA,
    version_from INTEGER NOT NULL,
    version_to INTEGER NOT NULL,
    partition_id INTEGER NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to,
                 partition_id)
) IN @DB_NAME@.EWSRR23;

CREATE UNIQUE INDEX @SCHEMA@.w_obj_pred_idx
 ON @SCHEMA@.w_obj_pred_index(obj_id, obj_typ_cd, version_from,
    version_to, partition_id);

