
--
--  Create temporary tables, copy the original data into them and drop the original tables
--      This is just to make sure all of the indexes and constraints on the original table are gone.
--      Indexes and constraints prevent the altering of nvarchar columns' collation settings.
--

CREATE TABLE w_temp_artifact_blob (
 id NVARCHAR(254) COLLATE Latin1_General_CS_AI NOT NULL, 
 content IMAGE, 
 deleted SMALLINT,
 PRIMARY KEY(id)
);

INSERT INTO w_temp_artifact_blob (id, content, deleted) SELECT * FROM w_artifact_blob;


CREATE TABLE w_temp_namespace (
    id int IDENTITY PRIMARY KEY CLUSTERED, 
    namespace nvarchar(254) COLLATE Latin1_General_CS_AI UNIQUE NOT NULL
);

SET IDENTITY_INSERT w_temp_namespace ON;
INSERT INTO w_temp_namespace (id, namespace) SELECT * FROM w_namespace;
SET IDENTITY_INSERT w_temp_namespace OFF;


CREATE TABLE w_temp_obj_lit_any (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL,
    type_uri nvarchar(254) COLLATE Latin1_General_CS_AI NOT NULL
);

SET IDENTITY_INSERT w_temp_obj_lit_any ON;
INSERT INTO w_temp_obj_lit_any (id, large, hash, type_uri) SELECT * FROM w_obj_lit_any;
SET IDENTITY_INSERT w_temp_obj_lit_any OFF;


CREATE TABLE w_temp_obj_lit_plain (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    litval nvarchar(1024) COLLATE Latin1_General_CS_AI NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL,
    xml_lang nvarchar(64) COLLATE Latin1_General_CS_AI NULL
);

SET IDENTITY_INSERT w_temp_obj_lit_plain ON;
INSERT INTO w_temp_obj_lit_plain (id, large, litval, hash, xml_lang) SELECT * FROM w_obj_lit_plain;
SET IDENTITY_INSERT w_temp_obj_lit_plain OFF;


CREATE TABLE w_temp_obj_lit_string (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    litval nvarchar(1024) COLLATE Latin1_General_CS_AI NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL
);

SET IDENTITY_INSERT w_temp_obj_lit_string ON;
INSERT INTO w_temp_obj_lit_string (id, large, litval, hash) SELECT * FROM w_obj_lit_string;
SET IDENTITY_INSERT w_temp_obj_lit_string OFF;


CREATE TABLE w_temp_uri (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    uri nvarchar(254) COLLATE Latin1_General_CS_AI UNIQUE NOT NULL,
    namespace_id int NOT NULL
);

SET IDENTITY_INSERT w_temp_uri ON;
INSERT INTO w_temp_uri (id, uri, namespace_id) SELECT * FROM w_uri;
SET IDENTITY_INSERT w_temp_uri OFF;


CREATE TABLE w_temp_statement (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    version_from int NOT NULL,
    version_to int NOT NULL,
    subj_id int NOT NULL,
    pred_id int NOT NULL,
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    partition_id int NOT NULL
);


SET IDENTITY_INSERT w_temp_statement ON;
INSERT INTO w_temp_statement (id, version_from, version_to, subj_id, pred_id, obj_id, obj_typ_cd, partition_id) SELECT * FROM w_statement;
SET IDENTITY_INSERT w_temp_statement OFF;


CREATE TABLE w_temp_version (
    id int NOT NULL,
    username nvarchar(64) COLLATE Latin1_General_CS_AI NOT NULL,
    change_time datetime NOT NULL,
    cl_gid nvarchar(36) COLLATE Latin1_General_CS_AI NULL,
    cl_lid nvarchar(10) COLLATE Latin1_General_CS_AI NULL,
    schema_ns_id int NULL,
    schema_rev int NULL,
    partition_id int NOT NULL
);

INSERT INTO w_temp_version (id, username, change_time, cl_gid, cl_lid, schema_ns_id, schema_rev, partition_id) SELECT * FROM w_version;


DROP TABLE w_artifact_blob;
DROP TABLE w_statement;
DROP TABLE w_version;
DROP TABLE w_uri;
DROP TABLE w_namespace;
DROP TABLE w_obj_lit_any;
DROP TABLE w_obj_lit_plain;
DROP TABLE w_obj_lit_string;

--
-- Recreate the tables with the new indexes
--

CREATE TABLE w_artifact_blob (
 id NVARCHAR(254) COLLATE Latin1_General_CS_AI NOT NULL, 
 content IMAGE, 
 deleted SMALLINT,
 PRIMARY KEY(id)
);

CREATE TABLE w_namespace (
    id int IDENTITY PRIMARY KEY CLUSTERED, 
    namespace nvarchar(254) COLLATE Latin1_General_CS_AI UNIQUE NOT NULL
);

CREATE UNIQUE INDEX idx_namespace ON w_namespace
    (namespace ASC) ;


CREATE TABLE w_obj_lit_any (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL,
    type_uri nvarchar(254) COLLATE Latin1_General_CS_AI NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_any ON w_obj_lit_any (type_uri);

CREATE TABLE w_obj_lit_plain (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    litval nvarchar(1024) COLLATE Latin1_General_CS_AI NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL,
    xml_lang nvarchar(64) COLLATE Latin1_General_CS_AI NULL
);

CREATE NONCLUSTERED INDEX IDX_OBJ_PLAIN ON w_obj_lit_plain
    (hash);


CREATE TABLE w_obj_lit_string (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    litval nvarchar(1024) COLLATE Latin1_General_CS_AI NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL
);

CREATE NONCLUSTERED INDEX IDX_OBJ_STR ON w_obj_lit_string
    (hash);


CREATE TABLE w_uri (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    uri nvarchar(254) COLLATE Latin1_General_CS_AI UNIQUE NOT NULL,
    namespace_id int NOT NULL
);

CREATE UNIQUE INDEX idx_uri ON w_uri (uri) ;
CREATE UNIQUE INDEX idx_uri_by_ns ON w_uri (namespace_id,id);

ALTER TABLE w_uri
    ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY (namespace_id) 
    REFERENCES w_namespace (id) 
    ON UPDATE NO ACTION
    ON DELETE NO ACTION;


CREATE TABLE w_version (
    id int NOT NULL,
    username nvarchar(64) COLLATE Latin1_General_CS_AI NOT NULL,
    change_time datetime NOT NULL,
    cl_gid nvarchar(36) COLLATE Latin1_General_CS_AI NULL,
    cl_lid nvarchar(10) COLLATE Latin1_General_CS_AI NULL,
    schema_ns_id int NULL,
    schema_rev int NULL,
    partition_id int NOT NULL
);

ALTER TABLE w_version ADD CONSTRAINT pk_version PRIMARY KEY CLUSTERED (id, partition_id);

CREATE NONCLUSTERED INDEX IDX_VER_SCHEMA ON w_version (schema_ns_id);

ALTER TABLE w_version
    ADD CONSTRAINT W_VER_FK_NAMESP FOREIGN KEY (schema_ns_id) 
    REFERENCES w_namespace (id) 
    ON UPDATE NO ACTION
    ON DELETE NO ACTION;


CREATE TABLE w_statement (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    version_from int NOT NULL,
    version_to int NOT NULL,
    subj_id int NOT NULL,
    pred_id int NOT NULL,
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    partition_id int NOT NULL
);

CREATE NONCLUSTERED INDEX IDX_SMT_BY_SBJ ON w_statement (subj_id, version_from, version_to);
CREATE NONCLUSTERED INDEX IDX_SMT_BY_FVR ON w_statement (version_from);
CREATE NONCLUSTERED INDEX IDX_SBJ_BY_PRP ON w_statement (pred_id, obj_id, partition_id);
CREATE NONCLUSTERED INDEX IDX_SBJ_BY_VAL ON w_statement (obj_id, subj_id);
CREATE NONCLUSTERED INDEX IDX_VAL_BY_PRP ON w_statement (subj_id, pred_id);


--
--  Copy the data from the temporary tables back into the original tables and drop the temporary tables
--

INSERT INTO w_artifact_blob (id, content, deleted) SELECT * FROM w_temp_artifact_blob;
DROP TABLE w_temp_artifact_blob;


SET IDENTITY_INSERT w_namespace ON;
INSERT INTO w_namespace (id, namespace) SELECT * FROM w_temp_namespace;
SET IDENTITY_INSERT w_namespace OFF;
DROP TABLE w_temp_namespace;


SET IDENTITY_INSERT w_obj_lit_any ON;
INSERT INTO w_obj_lit_any (id, large, hash, type_uri) SELECT * FROM w_temp_obj_lit_any;
SET IDENTITY_INSERT w_obj_lit_any OFF;
DROP TABLE w_temp_obj_lit_any;


SET IDENTITY_INSERT w_obj_lit_plain ON;
INSERT INTO w_obj_lit_plain (id, large, litval, hash, xml_lang) SELECT * FROM w_temp_obj_lit_plain;
SET IDENTITY_INSERT w_obj_lit_plain OFF;
DROP TABLE w_temp_obj_lit_plain;


SET IDENTITY_INSERT w_obj_lit_string ON;
INSERT INTO w_obj_lit_string (id, large, litval, hash) SELECT * FROM w_temp_obj_lit_string;
SET IDENTITY_INSERT w_obj_lit_string OFF;
DROP TABLE w_temp_obj_lit_string;


SET IDENTITY_INSERT w_uri ON;
INSERT INTO w_uri (id, uri, namespace_id) SELECT * FROM w_temp_uri;
SET IDENTITY_INSERT w_uri OFF;
DROP TABLE w_temp_uri;


INSERT INTO w_version (id, username, change_time, cl_gid, cl_lid, schema_ns_id, schema_rev, partition_id) SELECT * FROM w_temp_version;
DROP TABLE w_temp_version;


SET IDENTITY_INSERT w_statement ON;
INSERT INTO w_statement (id, version_from, version_to, subj_id, pred_id, obj_id, obj_typ_cd, partition_id) SELECT * FROM w_temp_statement;
SET IDENTITY_INSERT w_statement OFF;
DROP TABLE w_temp_statement;

-----------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2009 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------

CREATE TABLE w_locale (
    id int NOT NULL,
    locale nvarchar(8) COLLATE Latin1_General_CS_AI NOT NULL,
    PRIMARY KEY(id)
);

ALTER TABLE w_locale ADD CONSTRAINT unique_locale UNIQUE (locale);

INSERT INTO w_locale VALUES (1000, '');
INSERT INTO w_locale VALUES (1001, 'en');
INSERT INTO w_locale VALUES (1002, 'en-us');
INSERT INTO w_locale VALUES (1003, 'en-uk');
INSERT INTO w_locale VALUES (1004, 'en-gb');
INSERT INTO w_locale VALUES (1032, 'cs');
INSERT INTO w_locale VALUES (1064, 'es');
INSERT INTO w_locale VALUES (1096, 'de');
INSERT INTO w_locale VALUES (1128, 'de-de');
INSERT INTO w_locale VALUES (1129, 'fr');
INSERT INTO w_locale VALUES (1160, 'fr-ca-sk');
INSERT INTO w_locale VALUES (1161, 'hu');
INSERT INTO w_locale VALUES (1192, 'it');
INSERT INTO w_locale VALUES (1224, 'ja');
INSERT INTO w_locale VALUES (1256, 'ko');
INSERT INTO w_locale VALUES (1288, 'pl');
INSERT INTO w_locale VALUES (1320, 'pt-br');
INSERT INTO w_locale VALUES (1352, 'ru');
INSERT INTO w_locale VALUES (1384, 'zh');
INSERT INTO w_locale VALUES (1416, 'zh-tw');
INSERT INTO w_locale VALUES (1448, 'el');

-- Commit the active changeset which prevents the bootstrap of additional 
-- content either during migration or after installing stack product such as Fabric.
UPDATE w_statement 
        SET obj_id=(SELECT id FROM w_obj_lit_string WHERE litval='PUBLISHED') 
	WHERE pred_id=(SELECT id FROM w_uri WHERE uri LIKE '%changeSetState')
	AND obj_id IN (SELECT id FROM w_obj_lit_string WHERE litval IN ('DRAFT', 'PENDING' , 'APPROVED'))
	AND obj_typ_cd=6
	AND version_to=2000000000;

-- Can't drop plain until contents copied into 
-- w_string, with lang in w_statement.

UPDATE w_statement SET obj_id 
 = (SELECT w_lit_bool.litval FROM w_lit_bool
     WHERE w_statement.obj_id = w_lit_bool.id)
WHERE w_statement.obj_typ_cd = 7;

UPDATE w_statement SET obj_id 
 = (SELECT w_lit_int.litval FROM w_lit_int
     WHERE w_statement.obj_id = w_lit_int.id)
WHERE w_statement.obj_typ_cd = 2;

-- Merging string and plain:
-- 1. Canonicalize locale.

UPDATE w_obj_lit_plain SET xml_lang = '' WHERE xml_lang is null;


-- Guarantee no ID collisions during the copy:

UPDATE w_statement
   SET obj_id = (obj_id + (SELECT max(id) from w_obj_lit_string))
 WHERE obj_typ_cd = 11;

UPDATE w_obj_lit_plain 
  SET id = (id + (SELECT max(w_obj_lit_string.id) FROM w_obj_lit_string));

-- 3. Copy from plain into string table, with null  hash.

INSERT INTO w_obj_lit_string (id, large, litval) 
  SELECT id, large, litval
    FROM w_obj_lit_plain;

-- Use locale table to get type codes for plains.
UPDATE w_statement SET obj_typ_cd 
  = (SELECT w_locale.id FROM w_locale
      WHERE w_locale.locale =
              (SELECT w_obj_lit_plain.xml_lang 
                 FROM w_obj_lit_plain 
                WHERE w_statement.obj_id = w_obj_lit_plain.id))
WHERE w_statement.obj_typ_cd = 11;

-- The old object IDs in the string table haven't changed, but
-- the type code has. 
UPDATE w_statement SET obj_typ_cd = 999 WHERE obj_typ_cd = 6;

-- Cleanup

DROP TABLE w_obj_lit_plain;
DROP TABLE w_lit_int;
DROP TABLE w_lit_bool;

-- Pattern tables for query optimization

CREATE TABLE w_subj_pred_index (
    subj_id int NOT NULL REFERENCES w_uri (id),
    predicate_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY CLUSTERED (subj_id, version_from, version_to, partition_id)
);

CREATE TABLE w_subj_obj_index (
    subj_id int NOT NULL REFERENCES w_uri (id),
    object_map VARBINARY(1024),
    obj_typ_cd int NOT NULL,
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY CLUSTERED (subj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_pred_subj_index (
    pred_id int NOT NULL REFERENCES w_uri (id),
    subject_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY CLUSTERED (pred_id, version_from, version_to, partition_id)
);

CREATE TABLE w_pred_obj_index (
    pred_id int NOT NULL REFERENCES w_uri (id),
    object_map VARBINARY(1024),
    obj_typ_cd int NOT NULL,
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY CLUSTERED (pred_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_obj_subj_index (
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    subject_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY CLUSTERED (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_obj_pred_index (
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    predicate_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY CLUSTERED (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);

